"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toOptions = exports.fieldsToOptions = exports.templateToOptions = exports.clingGetApiToken = exports.clingApiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function clingApiRequest(apiToken, method, endpoint, body = {}, qs = {}) {
    const authenticationMethod = this.getNodeParameter('authentication', 0, 'basicAuth');
    let auth = {};
    if (authenticationMethod === 'basicAuth') {
        auth = { authorization: `JWT ${apiToken}` };
    }
    else {
        auth = { apikey: `${apiToken}` };
    }
    const options = {
        headers: {
            ...auth,
        },
        method,
        body,
        qs,
        uri: `https://api.cling.se/${endpoint}`,
        json: true,
        gzip: true,
        rejectUnauthorized: true,
    };
    if (Object.keys(qs).length === 0) {
        delete options.qs;
    }
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.clingApiRequest = clingApiRequest;
async function clingGetApiToken() {
    const authenticationMethod = this.getNodeParameter('authentication', 0, 'basicAuth');
    if (authenticationMethod === 'basicAuth') {
        const credentials = await this.getCredentials('clingCredentialsApi');
        const options = {
            headers: {},
            method: "post",
            body: {
                "email": credentials.email,
                "password": credentials.password,
            },
            uri: `https://api.cling.se/auth/companyUser`,
            json: true,
            gzip: true,
            rejectUnauthorized: true,
        };
        try {
            const authReply = await this.helpers.request(options);
            return authReply.token;
        }
        catch (error) {
            throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
        }
    }
    else {
        const credentials = await this.getCredentials('clingCredentialsApiTokenApi');
        return credentials.apiToken;
    }
}
exports.clingGetApiToken = clingGetApiToken;
const templateToOptions = (items) => items.map(({ name, _id }) => ({ name, value: _id }));
exports.templateToOptions = templateToOptions;
const fieldsToOptions = (items) => items.map(({ name, id }) => ({ name, value: id }));
exports.fieldsToOptions = fieldsToOptions;
const toOptions = (items) => items.map(({ name, id }) => ({ name, value: id }));
exports.toOptions = toOptions;
//# sourceMappingURL=GenericFunctions.js.map